require 'ougai'
require 'lograge'

require 'micro_common/meta_middleware'
require 'micro_common/store_request_id'

require 'micro_common/version'

module MicroCommon
  class Railtie < Rails::Railtie
    initializer 'add_middlewares' do |app|
      app.middleware.insert_after Rails::Rack::Logger, MicroCommon::MetaMiddleware
      app.middleware.insert_before ActionDispatch::RemoteIp, MicroCommon::StoreRequestId
    end

    config.logger = Ougai::Logger.new(STDOUT)
    config.logger.formatter = Ougai::Formatters::Readable.new if ENV['SIMPLE_LOGS']
    config.logger.before_log = lambda do |data|
      data[:request_id] = RequestStore.store[:request_id]
    end

    config.lograge.enabled = true
    config.lograge.base_controller_class = 'ActionController::API'
    config.lograge.formatter = Class.new do |fmt|
      def fmt.call(data)
        data
      end
    end

    Rails.logger = config.logger
    ActiveRecord::Base.logger = config.logger
  end
end
