module MicroCommon
  class MetaMiddleware
    def initialize(app)
      @app = app
    end

    def call(env)
      uri = env['PATH_INFO']

      if uri == '/meta/about'
        about
      elsif uri == '/meta/ping'
        ping
      elsif uri == '/meta/status'
        status
      else
        @app.call(env)
      end
    end

    def about
      response = JSON.pretty_generate(YAML.safe_load(File.read(Rails.root.join('config', 'about.yaml'))))
      [200, { 'Content-Type' => 'application/json' }, [response]]
    end

    def ping
      [200, {}, ['PONG']]
    end

    def status
      checks = run_checks
      status = checks.all? { |_, v| v } ? 200 : 503
      [status, { 'Content-Type' => 'application/json' }, [checks.to_json]]
    end

    def run_checks
      {
        database: check_database
      }
    end

    def check_database
      ActiveRecord::Base.connection.execute('SELECT 1')
      true
    rescue PG::Error, PG::ConnectionBad, ActiveRecord::NoDatabaseError
      false
    end
  end
end
